@@ -88,7 +88,7 @@ void AbstractDiskWriter::closeFile()
 void AbstractDiskWriter::openExistingFile(uint64_t totalLength)
 {
   if(!File(_filename).exists()) {
-    throw DlAbortEx
+    throw DL_ABORT_EX
       (StringFormat(EX_FILE_OPEN, _filename.c_str(), MSG_FILE_NOT_FOUND).str());
   }
 
@@ -100,7 +100,7 @@ void AbstractDiskWriter::openExistingFile(uint64_t totalLength)
   }
 
   if((fd = open(_filename.c_str(), flags, OPEN_MODE)) < 0) {
-    throw DlAbortEx
+    throw DL_ABORT_EX
       (StringFormat(EX_FILE_OPEN, _filename.c_str(), strerror(errno)).str());
   }
 }
@@ -111,7 +111,7 @@ void AbstractDiskWriter::createFile(int addFlags)
   Util::mkdirs(File(_filename).getDirname());
   if((fd = open(_filename.c_str(), O_CREAT|O_RDWR|O_TRUNC|O_BINARY|addFlags,
 		OPEN_MODE)) < 0) {
-    throw DlAbortEx(StringFormat(EX_FILE_OPEN,
+    throw DL_ABORT_EX(StringFormat(EX_FILE_OPEN,
 				 _filename.c_str(), strerror(errno)).str());
   }  
 }
@@ -140,7 +140,7 @@ ssize_t AbstractDiskWriter::readDataInternal(unsigned char* data, size_t len)
 void AbstractDiskWriter::seek(off_t offset)
 {
   if(lseek(fd, offset, SEEK_SET) == (off_t)-1) {
-    throw DlAbortEx
+    throw DL_ABORT_EX
       (StringFormat(EX_FILE_SEEK, _filename.c_str(), strerror(errno)).str());
   }
 }
@@ -152,10 +152,10 @@ void AbstractDiskWriter::writeData(const unsigned char* data, size_t len, off_t
     // If errno is ENOSPC(not enough space in device), throw
     // DownloadFailureException and abort download instantly.
     if(errno == ENOSPC) {
-      throw DownloadFailureException
+      throw DOWNLOAD_FAILURE_EXCEPTION
 	(StringFormat(EX_FILE_WRITE, _filename.c_str(), strerror(errno)).str());
     }
-    throw DlAbortEx(StringFormat(EX_FILE_WRITE,
+    throw DL_ABORT_EX(StringFormat(EX_FILE_WRITE,
 				 _filename.c_str(), strerror(errno)).str());
   }
 }
@@ -165,7 +165,7 @@ ssize_t AbstractDiskWriter::readData(unsigned char* data, size_t len, off_t offs
   ssize_t ret;
   seek(offset);
   if((ret = readDataInternal(data, len)) < 0) {
-    throw DlAbortEx(StringFormat(EX_FILE_READ,
+    throw DL_ABORT_EX(StringFormat(EX_FILE_READ,
 				 _filename.c_str(), strerror(errno)).str());
   }
   return ret;
@@ -174,7 +174,7 @@ ssize_t AbstractDiskWriter::readData(unsigned char* data, size_t len, off_t offs
 void AbstractDiskWriter::truncate(uint64_t length)
 {
   if(fd == -1) {
-    throw DlAbortEx("File not opened.");
+    throw DL_ABORT_EX("File not opened.");
   }
 #ifdef __MINGW32__
   // Since mingw32's ftruncate cannot handle over 2GB files, we use SetEndOfFile
@@ -182,12 +182,12 @@ void AbstractDiskWriter::truncate(uint64_t length)
   HANDLE handle = LongToHandle(_get_osfhandle(fd));
   seek(length);
   if(SetEndOfFile(handle) == 0) {
-    throw DlAbortEx(StringFormat("SetEndOfFile failed. cause: %s",
+    throw DL_ABORT_EX(StringFormat("SetEndOfFile failed. cause: %s",
 				 GetLastError()).str());
   }
 #else
   if(ftruncate(fd, length) == -1) {
-    throw DlAbortEx(StringFormat("ftruncate failed. cause: %s",
+    throw DL_ABORT_EX(StringFormat("ftruncate failed. cause: %s",
 				 strerror(errno)).str());
   }
 #endif
@@ -197,11 +197,11 @@ void AbstractDiskWriter::truncate(uint64_t length)
 void AbstractDiskWriter::allocate(off_t offset, uint64_t length)
 {
   if(fd == -1) {
-    throw DlAbortEx("File not yet opened.");
+    throw DL_ABORT_EX("File not yet opened.");
   }
   int r = posix_fallocate(fd, offset, length);
   if(r != 0) {
-    throw DlAbortEx(StringFormat("posix_fallocate failed. cause: %s",
+    throw DL_ABORT_EX(StringFormat("posix_fallocate failed. cause: %s",
 				 strerror(r)).str());
   }
 }
