@@ -207,11 +207,11 @@ DefaultBtAnnounce::processAnnounceResponse(const unsigned char* trackerResponse,
   const BDE dict =
     bencode::decode(trackerResponse, trackerResponseLength);
   if(!dict.isDict()) {
-    throw DlAbortEx(MSG_NULL_TRACKER_RESPONSE);
+    throw DL_ABORT_EX(MSG_NULL_TRACKER_RESPONSE);
   }
   const BDE& failure = dict[BtAnnounce::FAILURE_REASON];
   if(failure.isString()) {
-    throw DlAbortEx
+    throw DL_ABORT_EX
       (StringFormat(EX_TRACKER_FAILURE, failure.s().c_str()).str());
   }
   const BDE& warn = dict[BtAnnounce::WARNING_MESSAGE];
@@ -281,31 +281,16 @@ void DefaultBtAnnounce::setBtRuntime(const BtRuntimeHandle& btRuntime)
   this->btRuntime = btRuntime;
 }
 
-BtRuntimeHandle DefaultBtAnnounce::getBtRuntime() const
-{
-  return btRuntime;
-}
-
 void DefaultBtAnnounce::setPieceStorage(const PieceStorageHandle& pieceStorage)
 {
   this->pieceStorage = pieceStorage;
 }
 
-PieceStorageHandle DefaultBtAnnounce::getPieceStorage() const
-{
-  return pieceStorage;
-}
-
 void DefaultBtAnnounce::setPeerStorage(const PeerStorageHandle& peerStorage)
 {
   this->peerStorage = peerStorage;
 }
 
-PeerStorageHandle DefaultBtAnnounce::getPeerStorage() const
-{
-  return peerStorage;
-}
-
 void DefaultBtAnnounce::overrideMinInterval(time_t interval)
 {
   minInterval = interval;
