@@ -291,10 +291,10 @@ bool FtpConnection::bulkReceiveResponse(std::pair<unsigned int, std::string>& re
       if(socket->wantRead() || socket->wantWrite()) {
 	return false;
       }
-      throw DlRetryEx(EX_GOT_EOF);
+      throw DL_RETRY_EX(EX_GOT_EOF);
     }
     if(strbuf.size()+size > MAX_RECV_BUFFER) {
-      throw DlRetryEx
+      throw DL_RETRY_EX
 	(StringFormat("Max FTP recv buffer reached. length=%lu",
 		      static_cast<unsigned long>(strbuf.size()+size)).str());
     }
@@ -304,7 +304,7 @@ bool FtpConnection::bulkReceiveResponse(std::pair<unsigned int, std::string>& re
   if(strbuf.size() >= 4) {
     status = getStatus(strbuf);
     if(status == 0) {
-      throw DlAbortEx(EX_INVALID_RESPONSE);
+      throw DL_ABORT_EX(EX_INVALID_RESPONSE);
     }
   } else {
     return false;
@@ -411,7 +411,7 @@ unsigned int FtpConnection::receivePasvResponse(std::pair<std::string, uint16_t>
 	// port number
 	dest.second = 256*p1+p2;
       } else {
-	throw DlRetryEx(EX_INVALID_RESPONSE);
+	throw DL_RETRY_EX(EX_INVALID_RESPONSE);
       }
     }
     return response.first;
@@ -432,7 +432,7 @@ unsigned int FtpConnection::receivePwdResponse(std::string& pwd)
 	 (last = response.second.find("\"", ++first)) != std::string::npos) {
 	pwd = response.second.substr(first, last-first);
       } else {
-	throw DlAbortEx(EX_INVALID_RESPONSE);
+	throw DL_ABORT_EX(EX_INVALID_RESPONSE);
       }
     }
     return response.first;
@@ -446,9 +446,4 @@ void FtpConnection::setBaseWorkingDir(const std::string& baseWorkingDir)
   _baseWorkingDir = baseWorkingDir;
 }
 
-const std::string& FtpConnection::getBaseWorkingDir() const
-{
-  return _baseWorkingDir;
-}
-
 } // namespace aria2
