@@ -77,11 +77,11 @@ FtpNegotiationCommand::FtpNegotiationCommand(int32_t cuid,
   AbstractCommand(cuid, req, requestGroup, e, s), sequence(seq),
   ftp(new FtpConnection(cuid, socket, req,
 			e->getAuthConfigFactory()->createAuthConfig(req),
-			e->option))
+			getOption().get()))
 {
   ftp->setBaseWorkingDir(baseWorkingDir);
   if(seq == SEQ_RECV_GREETING) {
-    setTimeout(e->option->getAsInt(PREF_CONNECT_TIMEOUT));
+    setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
   }
   disableReadCheckSocket();
   setWriteCheckSocket(socket);
@@ -96,8 +96,8 @@ bool FtpNegotiationCommand::executeInternal() {
   } else if(sequence == SEQ_NEGOTIATION_COMPLETED) {
     FtpDownloadCommand* command =
       new FtpDownloadCommand(cuid, req, _requestGroup, ftp, e, dataSocket, socket);
-    command->setStartupIdleTime(e->option->getAsInt(PREF_STARTUP_IDLE_TIME));
-    command->setLowestDownloadSpeedLimit(e->option->getAsInt(PREF_LOWEST_SPEED_LIMIT));
+    command->setStartupIdleTime(getOption()->getAsInt(PREF_STARTUP_IDLE_TIME));
+    command->setLowestDownloadSpeedLimit(getOption()->getAsInt(PREF_LOWEST_SPEED_LIMIT));
     if(!_requestGroup->isSingleHostMultiConnectionEnabled()) {
       SharedHandle<ServerHost> sv =
 	_requestGroup->searchServerHost(req->getHost());
@@ -111,7 +111,7 @@ bool FtpNegotiationCommand::executeInternal() {
   } else if(sequence == SEQ_HEAD_OK || sequence == SEQ_DOWNLOAD_ALREADY_COMPLETED) {
     return true;
   } else if(sequence == SEQ_FILE_PREPARATION) {
-    if(e->option->getAsBool(PREF_FTP_PASV)) {
+    if(getOption()->getAsBool(PREF_FTP_PASV)) {
       sequence = SEQ_SEND_PASV;
     } else {
       sequence = SEQ_PREPARE_SERVER_SOCKET;
@@ -135,7 +135,7 @@ bool FtpNegotiationCommand::recvGreeting() {
     return false;
   }
   if(status != 220) {
-    throw DlAbortEx(EX_CONNECTION_FAILED);
+    throw DL_ABORT_EX(EX_CONNECTION_FAILED);
   }
   sequence = SEQ_SEND_USER;
 
@@ -164,7 +164,7 @@ bool FtpNegotiationCommand::recvUser() {
     sequence = SEQ_SEND_PASS;
     break;
   default:
-    throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   return true;
 }
@@ -185,7 +185,7 @@ bool FtpNegotiationCommand::recvPass() {
     return false;
   }
   if(status != 230) {
-    throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   sequence = SEQ_SEND_TYPE;
   return true;
@@ -207,7 +207,7 @@ bool FtpNegotiationCommand::recvType() {
     return false;
   }
   if(status != 200) {
-    throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   sequence = SEQ_SEND_PWD;
   return true;
@@ -232,7 +232,7 @@ bool FtpNegotiationCommand::recvPwd()
     return false;
   }
   if(status != 257) {
-    throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   ftp->setBaseWorkingDir(pwd);
   logger->info("CUID#%d - base working directory is '%s'", cuid, pwd.c_str());
@@ -261,11 +261,11 @@ bool FtpNegotiationCommand::recvCwd() {
     poolConnection();
     _requestGroup->increaseAndValidateFileNotFoundCount();
     if (status == 550)
-      throw DlAbortEx(MSG_RESOURCE_NOT_FOUND, DownloadResult::RESOURCE_NOT_FOUND);
+      throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND, DownloadResult::RESOURCE_NOT_FOUND);
     else
-      throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+      throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
-  if(e->option->getAsBool(PREF_REMOTE_TIME)) {
+  if(getOption()->getAsBool(PREF_REMOTE_TIME)) {
     sequence = SEQ_SEND_MDTM;
   } else {
     sequence = SEQ_SEND_SIZE;
@@ -330,19 +330,19 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
   dctx->setFilename(dctx->getDir()+"/"+Util::urldecode(req->getFile()));
   _requestGroup->preDownloadProcessing();
   if(e->_requestGroupMan->isSameFileBeingDownloaded(_requestGroup)) {
-    throw DownloadFailureException
+    throw DOWNLOAD_FAILURE_EXCEPTION
       (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
 		    _requestGroup->getFilePath().c_str()).str());
   }
   if(totalLength == 0) {
 
-    if(e->option->getAsBool(PREF_FTP_PASV)) {
+    if(getOption()->getAsBool(PREF_FTP_PASV)) {
       sequence = SEQ_SEND_PASV;
     } else {
       sequence = SEQ_PREPARE_SERVER_SOCKET;
     }
 
-    if(e->option->getAsBool(PREF_DRY_RUN)) {
+    if(getOption()->getAsBool(PREF_DRY_RUN)) {
       _requestGroup->initPieceStorage();
       onDryRunFileFound();
       return false;
@@ -378,15 +378,15 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
       (SharedHandle<BtProgressInfoFile>(new DefaultBtProgressInfoFile
 					(_requestGroup->getDownloadContext(),
 					 SharedHandle<PieceStorage>(),
-					 e->option)));
+					 getOption().get())));
     _requestGroup->initPieceStorage();
 
-    if(e->option->getAsBool(PREF_DRY_RUN)) {
+    if(getOption()->getAsBool(PREF_DRY_RUN)) {
       onDryRunFileFound();
       return false;
     }
 
-    BtProgressInfoFileHandle infoFile(new DefaultBtProgressInfoFile(_requestGroup->getDownloadContext(), _requestGroup->getPieceStorage(), e->option));
+    BtProgressInfoFileHandle infoFile(new DefaultBtProgressInfoFile(_requestGroup->getDownloadContext(), _requestGroup->getPieceStorage(), getOption().get()));
     if(!infoFile->exists() && _requestGroup->downloadFinishedByFileLength()) {
       _requestGroup->getPieceStorage()->markAllPiecesDone();
 
@@ -418,7 +418,7 @@ bool FtpNegotiationCommand::recvSize() {
   if(status == 213) {
 
     if(size > INT64_MAX) {
-      throw DlAbortEx
+      throw DL_ABORT_EX
 	(StringFormat(EX_TOO_LARGE_FILE, Util::uitos(size, true).c_str()).str());
     }
     if(_requestGroup->getPieceStorage().isNull()) {
@@ -448,7 +448,7 @@ bool FtpNegotiationCommand::recvSize() {
     // TODO Skipping RequestGroup::validateTotalLength(0) here will allow
     // wrong file to be downloaded if user-specified URL is wrong.
   }
-  if(e->option->getAsBool(PREF_FTP_PASV)) {
+  if(getOption()->getAsBool(PREF_FTP_PASV)) {
     sequence = SEQ_SEND_PASV;
   } else {
     sequence = SEQ_PREPARE_SERVER_SOCKET;
@@ -485,7 +485,7 @@ bool FtpNegotiationCommand::recvPort() {
     return false;
   }
   if(status != 200) {
-    throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   sequence = SEQ_SEND_REST;
   return true;
@@ -509,7 +509,7 @@ bool FtpNegotiationCommand::recvPasv() {
     return false;
   }
   if(status != 227) {
-    throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   // make a data connection to the server.
   logger->info(MSG_CONNECTING_TO_SERVER, cuid,
@@ -551,7 +551,7 @@ bool FtpNegotiationCommand::recvRest(const SharedHandle<Segment>& segment) {
   // then throw exception here.
   if(status != 350) {
     if(!segment.isNull() && segment->getPositionToWrite() != 0) {
-      throw DlAbortEx("FTP server doesn't support resuming.");
+      throw DL_ABORT_EX("FTP server doesn't support resuming.");
     }
   }
   sequence = SEQ_SEND_RETR;
@@ -576,11 +576,11 @@ bool FtpNegotiationCommand::recvRetr() {
   if(status != 150 && status != 125) {
     _requestGroup->increaseAndValidateFileNotFoundCount();
     if (status == 550)
-      throw DlAbortEx(MSG_RESOURCE_NOT_FOUND, DownloadResult::RESOURCE_NOT_FOUND);
+      throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND, DownloadResult::RESOURCE_NOT_FOUND);
     else
-      throw DlAbortEx(StringFormat(EX_BAD_STATUS, status).str());
+      throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
-  if(e->option->getAsBool(PREF_FTP_PASV)) {
+  if(getOption()->getAsBool(PREF_FTP_PASV)) {
     sequence = SEQ_NEGOTIATION_COMPLETED;
     return false;
   } else {
@@ -664,7 +664,7 @@ bool FtpNegotiationCommand::processSequence(const SegmentHandle& segment) {
 
 void FtpNegotiationCommand::poolConnection() const
 {
-  if(e->option->getAsBool(PREF_FTP_REUSE_CONNECTION)) {
+  if(getOption()->getAsBool(PREF_FTP_REUSE_CONNECTION)) {
     std::map<std::string, std::string> options;
     options["baseWorkingDir"] = ftp->getBaseWorkingDir();
     e->poolSocket(req, isProxyDefined(),  socket, options);
