@@ -63,16 +63,6 @@ HttpRequestEntry::HttpRequestEntry(const HttpRequestHandle& httpRequest):
 
 HttpRequestEntry::~HttpRequestEntry() {}
 
-HttpRequestHandle HttpRequestEntry::getHttpRequest() const
-{
-  return _httpRequest;
-}
-
-HttpHeaderProcessorHandle HttpRequestEntry::getHttpHeaderProcessor() const
-{
-  return _proc;
-}
-
 HttpConnection::HttpConnection(int32_t cuid,
 			       const SocketHandle& socket,
 			       const Option* op):
@@ -121,7 +111,7 @@ void HttpConnection::sendProxyRequest(const HttpRequestHandle& httpRequest)
 HttpResponseHandle HttpConnection::receiveResponse()
 {
   if(outstandingHttpRequests.empty()) {
-    throw DlAbortEx(EX_NO_HTTP_REQUEST_ENTRY_FOUND);
+    throw DL_ABORT_EX(EX_NO_HTTP_REQUEST_ENTRY_FOUND);
   }
   HttpRequestEntryHandle entry = outstandingHttpRequests.front();
   HttpHeaderProcessorHandle proc = entry->getHttpHeaderProcessor();
@@ -133,7 +123,7 @@ HttpResponseHandle HttpConnection::receiveResponse()
     if(socket->wantRead() || socket->wantWrite()) {
       return SharedHandle<HttpResponse>();
     } else {
-      throw DlRetryEx(EX_INVALID_RESPONSE);
+      throw DL_RETRY_EX(EX_INVALID_RESPONSE);
     }
   }
   proc->update(buf, size);
