@@ -33,6 +33,9 @@
  */
 /* copyright --> */
 #include "HttpServer.h"
+
+#include <sstream>
+
 #include "HttpHeader.h"
 #include "SocketCore.h"
 #include "HttpHeaderProcessor.h"
@@ -41,6 +44,7 @@
 #include "Util.h"
 #include "LogFactory.h"
 #include "Logger.h"
+#include "Base64.h"
 
 namespace aria2 {
 
@@ -50,7 +54,8 @@ HttpServer::HttpServer(const SharedHandle<SocketCore>& socket,
   _socketBuffer(socket),
   _e(e),
   _headerProcessor(new HttpHeaderProcessor()),
-  _logger(LogFactory::getInstance())
+  _logger(LogFactory::getInstance()),
+  _keepAlive(true)
 {}
 
 HttpServer::~HttpServer() {}
@@ -61,7 +66,7 @@ SharedHandle<HttpHeader> HttpServer::receiveRequest()
   unsigned char buf[size];
   _socket->peekData(buf, size);
   if(size == 0 && !(_socket->wantRead() || _socket->wantWrite())) {
-    throw DlAbortEx(EX_EOF_FROM_PEER);
+    throw DL_ABORT_EX(EX_EOF_FROM_PEER);
   }
   _headerProcessor->update(buf, size);
   if(!_headerProcessor->eoh()) {
@@ -77,14 +82,50 @@ SharedHandle<HttpHeader> HttpServer::receiveRequest()
     _logger->info("HTTP Server received request\n%s",
 		  _headerProcessor->getHeaderString().c_str());
     _lastRequestHeader = header;
+    _lastBody.clear();
+    _lastBody.str("");
+    _lastContentLength =
+      _lastRequestHeader->getFirstAsUInt(HttpHeader::CONTENT_LENGTH);
     _headerProcessor->clear();
   }
 
   return header;
 }
 
+bool HttpServer::receiveBody()
+{
+  if(_lastContentLength == 0) {
+    return true;
+  }
+  const size_t BUFLEN = 4096;
+  char buf[BUFLEN];
+  size_t length = std::min(BUFLEN,
+			   static_cast<size_t>
+			   (_lastContentLength-_lastBody.tellg()));
+  _socket->readData(buf, length);
+  if(length == 0 && !(_socket->wantRead() || _socket->wantWrite())) {
+    throw DL_ABORT_EX(EX_EOF_FROM_PEER);
+  }
+  _lastBody.write(buf, length);
+  return _lastContentLength == static_cast<uint64_t>(_lastBody.tellp());
+}
+
+std::string HttpServer::getBody() const
+{
+  return _lastBody.str();
+}
+
+const std::string& HttpServer::getRequestPath() const
+{
+  return _lastRequestHeader->getRequestPath();
+}
+
 bool HttpServer::supportsPersistentConnection() const
 {
+  if(!_keepAlive) {
+    return false;
+  }
+
   std::string connection =
     Util::toLower(_lastRequestHeader->getFirst(HttpHeader::CONNECTION));
 
@@ -93,15 +134,30 @@ bool HttpServer::supportsPersistentConnection() const
      connection.find("keep-alive") != std::string::npos);
 }
 
-void HttpServer::feedResponse(const std::string& text)
+void HttpServer::feedResponse(const std::string& text, const std::string& contentType)
 {
-  std::string header = "HTTP/1.1 200 OK\r\n"
-    "Content-Type: text/html\r\n"
+  feedResponse("200 OK", "", text, contentType);
+}
+
+void HttpServer::feedResponse(const std::string& status,
+			      const std::string& headers,
+			      const std::string& text,
+			      const std::string& contentType)
+{
+  std::string header = "HTTP/1.1 "+status+"\r\n"
+    "Content-Type: "+contentType+"\r\n"
     "Content-Length: "+Util::uitos(text.size())+"\r\n";
 
   if(!supportsPersistentConnection()) {
     header += "Connection: close\r\n";
   }
+  if(!headers.empty()) {
+    header += headers;
+    if(!Util::endsWith(headers, "\r\n")) {
+      header += "\r\n";
+    }
+  }
+
   header += "\r\n";
 
   _logger->debug("HTTP Server sends response:\n%s", header.c_str());
@@ -120,4 +176,23 @@ bool HttpServer::sendBufferIsEmpty() const
   return _socketBuffer.sendBufferIsEmpty();
 }
 
+bool HttpServer::authenticate()
+{
+  if(_username.empty()) {
+    return true;
+  }
+
+  std::string authHeader = _lastRequestHeader->getFirst("Authorization");
+  if(authHeader.empty()) {
+    return false;
+  }
+  std::pair<std::string, std::string> p = Util::split(authHeader, " ");
+  if(p.first != "Basic") {
+    return false;
+  }
+  std::string userpass = Base64::decode(p.second);
+  std::pair<std::string, std::string> userpassPair = Util::split(userpass, ":");
+  return _username == userpassPair.first && _password == userpassPair.second;
+}
+
 } // namespace aria2
