@@ -168,15 +168,17 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     handlers.push_back(op);
   }
 #endif // ENABLE_DIRECT_IO
+#ifdef ENABLE_XML_RPC
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
-				   (PREF_ENABLE_HTTP_SERVER,
-				    TEXT_ENABLE_HTTP_SERVER,
+				   (PREF_ENABLE_XML_RPC,
+				    TEXT_ENABLE_XML_RPC,
 				    V_FALSE,
 				    OptionHandler::OPT_ARG));
-    op->addTag(TAG_EXPERIMENTAL);
+    op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
+#endif // ENABLE_XML_RPC
   {
     std::string params[] = {
 #ifdef HAVE_EPOLL
@@ -220,15 +222,6 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_BASIC);
     handlers.push_back(op);
   }
-  {
-    SharedHandle<OptionHandler> op(new NumberOptionHandler
-				   (PREF_HTTP_SERVER_LISTEN_PORT,
-				    TEXT_HTTP_SERVER_LISTEN_PORT,
-				    "6800",
-				    1024, UINT16_MAX));
-    op->addTag(TAG_EXPERIMENTAL);
-    handlers.push_back(op);
-  }
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
 				   (PREF_INPUT_FILE,
@@ -313,6 +306,42 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_ON_DOWNLOAD_COMPLETE,
+				    TEXT_ON_DOWNLOAD_COMPLETE,
+				    NO_DEFAULT_VALUE,
+				    "/path/to/command"));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_ON_DOWNLOAD_ERROR,
+				    TEXT_ON_DOWNLOAD_ERROR,
+				    NO_DEFAULT_VALUE,
+				    "/path/to/command"));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_ON_DOWNLOAD_START,
+				    TEXT_ON_DOWNLOAD_START,
+				    NO_DEFAULT_VALUE,
+				    "/path/to/command"));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_ON_DOWNLOAD_STOP,
+				    TEXT_ON_DOWNLOAD_STOP,
+				    NO_DEFAULT_VALUE,
+				    "/path/to/command"));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
 				   (PREF_PARAMETERIZED_URI,
@@ -361,6 +390,40 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
+#ifdef ENABLE_XML_RPC
+  {
+    SharedHandle<OptionHandler> op(new NumberOptionHandler
+				   (PREF_XML_RPC_LISTEN_PORT,
+				    TEXT_XML_RPC_LISTEN_PORT,
+				    "6800",
+				    1024, UINT16_MAX));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new UnitNumberOptionHandler
+				   (PREF_XML_RPC_MAX_REQUEST_SIZE,
+				    TEXT_XML_RPC_MAX_REQUEST_SIZE,
+				    "2M",
+				    0));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }			    
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_XML_RPC_USER,
+				    TEXT_XML_RPC_USER));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_XML_RPC_PASSWD,
+				    TEXT_XML_RPC_PASSWD));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }			    
+#endif // ENABLE_XML_RPC
   // HTTP/FTP options
   {
     SharedHandle<OptionHandler> op(new NumberOptionHandler
@@ -413,6 +476,17 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new BooleanOptionHandler
+				   (PREF_NO_NETRC,
+				    TEXT_NO_NETRC,
+				    V_FALSE, // TODO ommit?
+				    OptionHandler::NO_ARG,
+				    'n'));
+    op->addTag(TAG_FTP);
+    op->addTag(TAG_HTTP);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
 				   (PREF_OUT,
@@ -641,7 +715,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
 				   (PREF_LOAD_COOKIES,
 				    TEXT_LOAD_COOKIES,
 				    NO_DEFAULT_VALUE,
-				    "FILENAME"));
+				    "/path/to/file"));
     op->addTag(TAG_BASIC);
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -670,6 +744,15 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_SAVE_COOKIES,
+				    TEXT_SAVE_COOKIES,
+				    NO_DEFAULT_VALUE,
+				    "/path/to/file"));
+    op->addTag(TAG_HTTP);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
 				   (PREF_USE_HEAD,
@@ -744,17 +827,6 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->hide();
     handlers.push_back(op);
   }
-  {
-    SharedHandle<OptionHandler> op(new BooleanOptionHandler
-				   (PREF_NO_NETRC,
-				    TEXT_NO_NETRC,
-				    V_FALSE, // TODO ommit?
-				    OptionHandler::NO_ARG,
-				    'n'));
-    op->addTag(TAG_FTP);
-    op->addTag(TAG_HTTP);
-    handlers.push_back(op);
-  }
   // Proxy options
   {
     SharedHandle<OptionHandler> op(new HttpProxyOptionHandler
