@@ -95,16 +95,6 @@ Piece& Piece::operator=(const Piece& piece)
   return *this;
 }
 
-bool Piece::operator==(const Piece& piece) const
-{
-  return index == piece.index;
-}
-
-bool Piece::operator<(const Piece& piece) const
-{
-  return index < piece.index;
-}
-
 void Piece::completeBlock(size_t blockIndex) {
   bitfield->setBit(blockIndex);
   bitfield->unsetUseBit(blockIndex);
