@@ -110,18 +110,20 @@ int32_t RequestGroup::_gidCounter = 0;
 
 const std::string RequestGroup::ACCEPT_METALINK = "application/metalink+xml";
 
-RequestGroup::RequestGroup(const Option* option,
+RequestGroup::RequestGroup(const SharedHandle<Option>& option,
 			   const std::deque<std::string>& uris):
   _gid(++_gidCounter),
+  _option(new Option(*option.get())),
   _uris(uris),
   _numConcurrentCommand(option->getAsInt(PREF_SPLIT)),
   _numStreamConnection(0),
   _numCommand(0),
-  _segmentManFactory(new DefaultSegmentManFactory(option)),
+  _segmentManFactory(new DefaultSegmentManFactory(_option.get())),
   _progressInfoFile(new NullProgressInfoFile()),
   _preLocalFileCheckEnabled(true),
   _haltRequested(false),
   _forceHaltRequested(false),
+  _haltReason(RequestGroup::NONE),
   _singleHostMultiConnectionEnabled(true),
   _uriSelector(new InOrderURISelector()),
   _lastModifiedTime(Time::null()),
@@ -131,7 +133,6 @@ RequestGroup::RequestGroup(const Option* option,
   _inMemoryDownload(false),
   _maxDownloadSpeedLimit(option->getAsInt(PREF_MAX_DOWNLOAD_LIMIT)),
   _maxUploadSpeedLimit(option->getAsInt(PREF_MAX_UPLOAD_LIMIT)),
-  _option(option),
   _logger(LogFactory::getInstance())
 {
   _fileAllocationEnabled = _option->get(PREF_FILE_ALLOCATION) != V_NONE;
@@ -148,7 +149,7 @@ RequestGroup::RequestGroup(const Option* option,
 
 RequestGroup::~RequestGroup() {}
 
-SegmentManHandle RequestGroup::initSegmentMan()
+const SegmentManHandle& RequestGroup::initSegmentMan()
 {
   _segmentMan = _segmentManFactory->createNewInstance(_downloadContext,
 						      _pieceStorage);
@@ -179,7 +180,11 @@ DownloadResult::RESULT RequestGroup::downloadResult() const
     return DownloadResult::FINISHED;
   else {
     if (_uriResults.empty()) {
-      return DownloadResult::UNKNOWN_ERROR;
+      if(_haltReason == RequestGroup::USER_REQUEST) {
+	return DownloadResult::IN_PROGRESS;
+      } else {
+	return DownloadResult::UNKNOWN_ERROR;
+      }
     } else {
       return _uriResults.back().getResult();
     }
@@ -202,18 +207,18 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
     BtContextHandle btContext = dynamic_pointer_cast<BtContext>(_downloadContext);
     if(!btContext.isNull()) {
       if(_option->getAsBool(PREF_DRY_RUN)) {
-	throw DownloadFailureException
+	throw DOWNLOAD_FAILURE_EXCEPTION
 	  ("Cancel BitTorrent download in dry-run context.");
       }
       SharedHandle<BtRegistry> btRegistry = e->getBtRegistry();
       if(!btRegistry->getBtContext(btContext->getInfoHashAsString()).isNull()) {
-	throw DownloadFailureException
+	throw DOWNLOAD_FAILURE_EXCEPTION
 	  (StringFormat("InfoHash %s is already registered.",
 			btContext->getInfoHashAsString().c_str()).str());
       }
 
       if(e->_requestGroupMan->isSameFileBeingDownloaded(this)) {
-	throw DownloadFailureException
+	throw DOWNLOAD_FAILURE_EXCEPTION
 	  (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
 			getFilePath().c_str()).str());
       }
@@ -225,7 +230,7 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
 	_logger->debug("Clearing http/ftp URIs because the current implementation does not allow integrating multi-file torrent and http/ftp.");
 	_uris.clear();
 
-	_pieceStorage->setFileFilter(btContext->getFileFilter());
+	_pieceStorage->setupFileFilter();
       } else if(btContext->getFileEntries().size() == 1) {
 	// web-seeding is only enabled for single file torrent
 	SharedHandle<FileEntry> fileEntry = btContext->getFileEntries().front();
@@ -237,7 +242,7 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
       SharedHandle<DefaultBtProgressInfoFile>
 	progressInfoFile(new DefaultBtProgressInfoFile(_downloadContext,
 						       _pieceStorage,
-						       _option));
+						       _option.get()));
       
       btRegistry->registerBtContext(btContext->getInfoHashAsString(),
 				    btContext);
@@ -256,7 +261,7 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
       progressInfoFile->setBtRuntime(btRuntime);
 
       SharedHandle<DefaultPeerStorage> peerStorage
-	(new DefaultPeerStorage(btContext, _option));
+	(new DefaultPeerStorage(btContext, _option.get()));
       peerStorage->setBtRuntime(btRuntime);
       peerStorage->setPieceStorage(_pieceStorage);
       btRegistry->registerPeerStorage(btContext->getInfoHashAsString(),
@@ -265,7 +270,7 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
       progressInfoFile->setPeerStorage(peerStorage);
 
       SharedHandle<DefaultBtAnnounce> btAnnounce
-	(new DefaultBtAnnounce(btContext, _option));
+	(new DefaultBtAnnounce(btContext, _option.get()));
       btAnnounce->setBtRuntime(btRuntime);
       btAnnounce->setPieceStorage(_pieceStorage);
       btAnnounce->setPeerStorage(peerStorage);
@@ -308,7 +313,7 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
 	     !_option->getAsBool(PREF_ALLOW_OVERWRITE) &&
 	     !_option->getAsBool(PREF_BT_SEED_UNVERIFIED)) {
 	    // TODO we need this->haltRequested = true?
-	    throw DownloadFailureException
+	    throw DOWNLOAD_FAILURE_EXCEPTION
 	      (StringFormat
 	       (MSG_FILE_ALREADY_EXISTS,
 		getFilePath().c_str()).str());
@@ -326,7 +331,7 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
 
       if(!btContext->isPrivate() && _option->getAsBool(PREF_ENABLE_DHT)) {
 	std::deque<Command*> commands;
-	DHTSetup().setup(commands, e, _option);
+	DHTSetup().setup(commands, e, _option.get());
 	e->addCommand(commands);
 	if(!btContext->getNodes().empty() && DHTSetup::initialized()) {
 	  DHTEntryPointNameResolveCommand* command =
@@ -359,7 +364,7 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
     createNextCommand(commands, e, 1, method);
   }else {
     if(e->_requestGroupMan->isSameFileBeingDownloaded(this)) {
-      throw DownloadFailureException
+      throw DOWNLOAD_FAILURE_EXCEPTION
 	(StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
 		      getFilePath().c_str()).str());
     }
@@ -367,10 +372,11 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
       (SharedHandle<BtProgressInfoFile>(new DefaultBtProgressInfoFile
 					(_downloadContext,
 					 SharedHandle<PieceStorage>(),
-					 _option)));
+					 _option.get())));
     initPieceStorage();
     BtProgressInfoFileHandle infoFile
-      (new DefaultBtProgressInfoFile(_downloadContext, _pieceStorage, _option));
+      (new DefaultBtProgressInfoFile(_downloadContext, _pieceStorage,
+				     _option.get()));
     if(!infoFile->exists() && downloadFinishedByFileLength()) {
       _pieceStorage->markAllPiecesDone();
       _logger->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
@@ -389,7 +395,7 @@ void RequestGroup::processCheckIntegrityEntry(std::deque<Command*>& commands,
 					      DownloadEngine* e)
 {
 #ifdef ENABLE_MESSAGE_DIGEST
-  if(e->option->getAsBool(PREF_CHECK_INTEGRITY) &&
+  if(_option->getAsBool(PREF_CHECK_INTEGRITY) &&
      entry->isValidationReady()) {
     entry->initValidator();
     entry->cutTrailingGarbage();
@@ -406,7 +412,7 @@ void RequestGroup::initPieceStorage()
   if(_downloadContext->knowsTotalLength()) {
 #ifdef ENABLE_BITTORRENT
     SharedHandle<DefaultPieceStorage> ps
-      (new DefaultPieceStorage(_downloadContext, _option));
+      (new DefaultPieceStorage(_downloadContext, _option.get()));
     // Use LongestSequencePieceSelector when HTTP/FTP/BitTorrent integrated
     // downloads. Currently multi-file integrated download is not supported.
     if(!_uris.empty() &&
@@ -418,7 +424,7 @@ void RequestGroup::initPieceStorage()
     }
 #else // !ENABLE_BITTORRENT
     SharedHandle<DefaultPieceStorage> ps
-      (new DefaultPieceStorage(_downloadContext, _option));
+      (new DefaultPieceStorage(_downloadContext, _option.get()));
 #endif // !ENABLE_BITTORRENT
     if(!_diskWriterFactory.isNull()) {
       ps->setDiskWriterFactory(_diskWriterFactory);
@@ -426,7 +432,7 @@ void RequestGroup::initPieceStorage()
     _pieceStorage = ps;
   } else {
     UnknownLengthPieceStorageHandle ps
-      (new UnknownLengthPieceStorage(_downloadContext, _option));
+      (new UnknownLengthPieceStorage(_downloadContext, _option.get()));
     if(!_diskWriterFactory.isNull()) {
       ps->setDiskWriterFactory(_diskWriterFactory);
     }
@@ -523,7 +529,7 @@ void RequestGroup::loadAndOpenFile(const BtProgressInfoFileHandle& progressInfoF
     }
     setProgressInfoFile(progressInfoFile);
   } catch(RecoverableException& e) {
-    throw DownloadFailureException
+    throw DOWNLOAD_FAILURE_EXCEPTION2
       (StringFormat(EX_DOWNLOAD_ABORTED).str(), e);
   }
 }
@@ -540,12 +546,12 @@ void RequestGroup::shouldCancelDownloadForSafety()
       if(tryAutoFileRenaming()) {
 	_logger->notice(MSG_FILE_RENAMED, getFilePath().c_str());
       } else {
-	throw DownloadFailureException
+	throw DOWNLOAD_FAILURE_EXCEPTION
 	  (StringFormat("File renaming failed: %s",
 			getFilePath().c_str()).str());
       }
     } else {
-      throw DownloadFailureException
+      throw DOWNLOAD_FAILURE_EXCEPTION
 	(StringFormat(MSG_FILE_ALREADY_EXISTS,
 		      getFilePath().c_str()).str());
     }
@@ -716,7 +722,7 @@ void RequestGroup::validateFilename(const std::string& expectedFilename,
     return;
   }
   if(expectedFilename != actualFilename) {
-    throw DlAbortEx(StringFormat(EX_FILENAME_MISMATCH,
+    throw DL_ABORT_EX(StringFormat(EX_FILENAME_MISMATCH,
 				 expectedFilename.c_str(),
 				 actualFilename.c_str()).str());
   }
@@ -729,7 +735,7 @@ void RequestGroup::validateTotalLength(uint64_t expectedTotalLength,
     return;
   }
   if(expectedTotalLength != actualTotalLength) {
-    throw DlAbortEx
+    throw DL_ABORT_EX
       (StringFormat(EX_SIZE_MISMATCH,
 		    Util::itos(expectedTotalLength, true).c_str(),
 		    Util::itos(actualTotalLength, true).c_str()).str());
@@ -792,9 +798,12 @@ TransferStat RequestGroup::calculateStat()
   return stat;
 }
 
-void RequestGroup::setHaltRequested(bool f)
+void RequestGroup::setHaltRequested(bool f, HaltReason haltReason)
 {
   _haltRequested = f;
+  if(_haltRequested) {
+    _haltReason = haltReason;
+  }
 #ifdef ENABLE_BITTORRENT
   if(!_btRuntime.isNull()) {
     _btRuntime->setHalt(f);
@@ -802,9 +811,9 @@ void RequestGroup::setHaltRequested(bool f)
 #endif // ENABLE_BITTORRENT
 }
 
-void RequestGroup::setForceHaltRequested(bool f)
+void RequestGroup::setForceHaltRequested(bool f, HaltReason haltReason)
 {
-  setHaltRequested(f);
+  setHaltRequested(f, haltReason);
   _forceHaltRequested = f;
 }
 
@@ -928,11 +937,6 @@ void RequestGroup::setDiskWriterFactory(const DiskWriterFactoryHandle& diskWrite
   _diskWriterFactory = diskWriterFactory;
 }
 
-DiskWriterFactoryHandle RequestGroup::getDiskWriterFactory() const
-{
-  return _diskWriterFactory;
-}
-
 void RequestGroup::addPostDownloadHandler(const PostDownloadHandlerHandle& handler)
 {
   _postDownloadHandlers.push_back(handler);
@@ -953,36 +957,16 @@ void RequestGroup::clearPreDowloadHandler()
   _preDownloadHandlers.clear();
 }
 
-SegmentManHandle RequestGroup::getSegmentMan() const
-{
-  return _segmentMan;
-}
-
-DownloadContextHandle RequestGroup::getDownloadContext() const
-{
-  return _downloadContext;
-}
-
 void RequestGroup::setDownloadContext(const DownloadContextHandle& downloadContext)
 {
   _downloadContext = downloadContext;
 }
 
-PieceStorageHandle RequestGroup::getPieceStorage() const
-{
-  return _pieceStorage;
-}
-
 void RequestGroup::setPieceStorage(const PieceStorageHandle& pieceStorage)
 {
   _pieceStorage = pieceStorage;
 }
 
-BtProgressInfoFileHandle RequestGroup::getProgressInfoFile() const
-{
-  return _progressInfoFile;
-}
-
 void RequestGroup::setProgressInfoFile(const BtProgressInfoFileHandle& progressInfoFile)
 {
   _progressInfoFile = progressInfoFile;
@@ -1016,7 +1000,8 @@ DownloadResultHandle RequestGroup::createDownloadResult() const
   return
     SharedHandle<DownloadResult>
     (new DownloadResult(_gid,
-			getFilePath(),
+			_downloadContext->getFileEntries(),
+			_inMemoryDownload,
 			getTotalLength(),
 			uris.empty() ? A2STR::NIL:uris.front(),
 			uris.size(),
@@ -1121,11 +1106,6 @@ void RequestGroup::reportDownloadFinished()
 #endif // ENABLE_BITTORRENT
 }
 
-const std::deque<std::string>& RequestGroup::getAcceptFeatures() const
-{
-  return _acceptFeatures;
-}
-
 void RequestGroup::addAcceptFeatureHeader(const std::string& feature)
 {
   if(std::find(_acceptFeatures.begin(), _acceptFeatures.end(), feature) == _acceptFeatures.end()) {
@@ -1141,11 +1121,6 @@ void RequestGroup::removeAcceptFeatureHeader(const std::string& feature)
   }
 }
 
-const std::deque<std::string>& RequestGroup::getAcceptTypes() const
-{
-  return _acceptTypes;
-}
-
 void RequestGroup::addAcceptType(const std::string& type)
 {
   if(std::find(_acceptTypes.begin(), _acceptTypes.end(), type) == _acceptTypes.end()) {
@@ -1190,27 +1165,17 @@ void RequestGroup::increaseAndValidateFileNotFoundCount()
   const unsigned int maxCount = _option->getAsInt(PREF_MAX_FILE_NOT_FOUND);
   if(maxCount > 0 && _fileNotFoundCount >= maxCount &&
      _segmentMan->calculateSessionDownloadLength() == 0) {
-    throw DownloadFailureException
+    throw DOWNLOAD_FAILURE_EXCEPTION2
       (StringFormat("Reached max-file-not-found count=%u", maxCount).str(),
        DownloadResult::MAX_FILE_NOT_FOUND);
   }
 }
 
-unsigned int RequestGroup::getNumConcurrentCommand() const
-{
-  return _numConcurrentCommand;
-}
-
 void RequestGroup::markInMemoryDownload()
 {
   _inMemoryDownload = true;
 }
 
-bool RequestGroup::inMemoryDownload() const
-{
-  return _inMemoryDownload;
-}
-
 void RequestGroup::tuneDownloadCommand(DownloadCommand* command)
 {
   _uriSelector->tuneDownloadCommand(_uris, command);
@@ -1221,11 +1186,6 @@ void RequestGroup::addURIResult(std::string uri, DownloadResult::RESULT result)
   _uriResults.push_back(URIResult(uri, result));
 }
 
-const std::deque<URIResult>& RequestGroup::getURIResults() const
-{
-  return _uriResults;
-}
-
 class FindURIResultByResult {
 private:
   DownloadResult::RESULT _r;
@@ -1253,21 +1213,11 @@ void RequestGroup::setTimeout(time_t timeout)
   _timeout = timeout;
 }
 
-time_t RequestGroup::getTimeout() const
-{
-  return _timeout;
-}
-
 void RequestGroup::setMaxTries(unsigned int maxTries)
 {
   _maxTries = maxTries;
 }
 
-unsigned int RequestGroup::getMaxTries() const
-{
-  return _maxTries;
-}
-
 bool RequestGroup::doesDownloadSpeedExceed()
 {
   return _maxDownloadSpeedLimit > 0 &&
