@@ -34,6 +34,8 @@
 /* copyright --> */
 #include "RequestGroupMan.h"
 
+#include <unistd.h>
+#include <cstring>
 #include <iomanip>
 #include <sstream>
 #include <ostream>
@@ -83,6 +85,11 @@ RequestGroupMan::RequestGroupMan(const RequestGroups& requestGroups,
 
 bool RequestGroupMan::downloadFinished()
 {
+#ifdef ENABLE_XML_RPC
+  if(_option->getAsBool(PREF_ENABLE_XML_RPC)) {
+    return false;
+  }
+#endif // ENABLE_XML_RPC
   if(!_reservedGroups.empty()) {
     return false;
   }
@@ -105,11 +112,26 @@ void RequestGroupMan::addReservedGroup(const RequestGroups& groups)
   _reservedGroups.insert(_reservedGroups.end(), groups.begin(), groups.end());
 }
 
-void RequestGroupMan::addReservedGroup(const RequestGroupHandle& group)
+void RequestGroupMan::addReservedGroup(const SharedHandle<RequestGroup>& group)
 {
   _reservedGroups.push_back(group);
 }
 
+void RequestGroupMan::insertReservedGroup
+(size_t pos, const std::deque<SharedHandle<RequestGroup> >& groups)
+{
+  _reservedGroups.insert
+    (_reservedGroups.begin()+std::min(_reservedGroups.size(), pos),
+     groups.begin(), groups.end());
+}
+
+void RequestGroupMan::insertReservedGroup
+(size_t pos, const SharedHandle<RequestGroup>& group)
+{
+  _reservedGroups.insert
+    (_reservedGroups.begin()+std::min(_reservedGroups.size(), pos), group);
+}
+
 size_t RequestGroupMan::countRequestGroup() const
 {
   return _requestGroups.size();
@@ -124,10 +146,88 @@ RequestGroupHandle RequestGroupMan::getRequestGroup(size_t index) const
   }
 }
 
-const std::deque<SharedHandle<RequestGroup> >&
-RequestGroupMan::getRequestGroups() const
+template<typename Iterator>
+static Iterator findByGID(Iterator first, Iterator last, int32_t gid)
 {
-  return _requestGroups;
+  for(; first != last; ++first) {
+    if((*first)->getGID() == gid) {
+      return first;
+    }
+  }
+  return first;
+}
+
+SharedHandle<RequestGroup>
+RequestGroupMan::findRequestGroup(int32_t gid) const
+{
+  std::deque<SharedHandle<RequestGroup> >::const_iterator i =
+    findByGID(_requestGroups.begin(), _requestGroups.end(), gid);
+  if(i == _requestGroups.end()) {
+    return SharedHandle<RequestGroup>();
+  } else {
+    return *i;
+  }
+}
+
+SharedHandle<RequestGroup>
+RequestGroupMan::findReservedGroup(int32_t gid) const
+{
+  std::deque<SharedHandle<RequestGroup> >::const_iterator i =
+    findByGID(_reservedGroups.begin(), _reservedGroups.end(), gid);
+  if(i == _reservedGroups.end()) {
+    return SharedHandle<RequestGroup>();
+  } else {
+    return *i;
+  }
+}
+
+bool RequestGroupMan::removeReservedGroup(int32_t gid)
+{
+  std::deque<SharedHandle<RequestGroup> >::iterator i =
+    findByGID(_reservedGroups.begin(), _reservedGroups.end(), gid);
+  if(i == _reservedGroups.end()) {
+    return false;
+  } else {
+    _reservedGroups.erase(i);
+    return true;
+  }
+}
+
+static void executeHook(const std::string& command, int gid)
+{
+  LogFactory::getInstance()->info("Executing user command: %s %d",
+				  command.c_str(), gid);
+  pid_t cpid = fork();
+  if(cpid == -1) {
+    LogFactory::getInstance()->error("fork() failed."
+				     " Cannot execute user command.");
+  } else if(cpid == 0) {
+    execl(command.c_str(), command.c_str(), Util::itos(gid).c_str(), (char*)0);
+    perror(("Could not execute user command: "+command).c_str());
+    _exit(1);
+  }
+}
+
+static void executeStartHook
+(const SharedHandle<RequestGroup>& group, const Option* option)
+{
+  if(!option->blank(PREF_ON_DOWNLOAD_START)) {
+    executeHook(option->get(PREF_ON_DOWNLOAD_START), group->getGID());
+  }
+}
+
+static void executeStopHook
+(const SharedHandle<DownloadResult>& result, const Option* option)
+{
+  if(result->result == DownloadResult::FINISHED &&
+     !option->blank(PREF_ON_DOWNLOAD_COMPLETE)) {
+    executeHook(option->get(PREF_ON_DOWNLOAD_COMPLETE), result->gid);
+  } else if(result->result != DownloadResult::IN_PROGRESS &&
+	    !option->blank(PREF_ON_DOWNLOAD_ERROR)) {
+    executeHook(option->get(PREF_ON_DOWNLOAD_ERROR), result->gid);
+  } else if(!option->blank(PREF_ON_DOWNLOAD_STOP)) {
+    executeHook(option->get(PREF_ON_DOWNLOAD_STOP), result->gid);
+  }
 }
 
 class ProcessStoppedRequestGroup {
@@ -193,6 +293,8 @@ public:
       }
       group->releaseRuntimeResource(_e);
       _downloadResults.push_back(group->createDownloadResult());
+
+      executeStopHook(_downloadResults.back(), _e->option);
     }
   }
 };
@@ -303,11 +405,14 @@ static void createInitialCommand(const SharedHandle<RequestGroup>& requestGroup,
 
 void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
 {
-  RequestGroups temp;
   removeStoppedGroup(e);
+  if(_maxSimultaneousDownloads <= _requestGroups.size()) {
+    return;
+  }
+  RequestGroups temp;
   unsigned int count = 0;
-  for(int num = _maxSimultaneousDownloads-_requestGroups.size();
-      num > 0 && !_reservedGroups.empty(); --num) {
+  size_t num = _maxSimultaneousDownloads-_requestGroups.size();
+  while(count < num && !_reservedGroups.empty()) {
     RequestGroupHandle groupToAdd = _reservedGroups.front();
     _reservedGroups.pop_front();
     try {
@@ -323,8 +428,10 @@ void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
       _requestGroups.push_back(groupToAdd);
       ++count;
       e->addCommand(commands);
+      executeStartHook(groupToAdd, e->option);
     } catch(RecoverableException& ex) {
       _logger->error(EX_EXCEPTION_CAUGHT, ex);
+      groupToAdd->releaseRuntimeResource(e);
       _downloadResults.push_back(groupToAdd->createDownloadResult());
     }
   }
@@ -345,6 +452,7 @@ void RequestGroupMan::getInitialCommands(std::deque<Command*>& commands,
 	configureRequestGroup(*itr);
 	createInitialCommand(*itr, commands, e,
 			     _option->getAsBool(PREF_USE_HEAD));
+	executeStartHook(*itr, e->option);
 	++itr;
       } else {
 	_reservedGroups.push_front((*itr));
@@ -434,6 +542,9 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
     if((*itr)->result == DownloadResult::FINISHED) {
       status = MARK_OK;
       ++ok;
+    } else if((*itr)->result == DownloadResult::IN_PROGRESS) {
+      status = MARK_INPR;
+      ++inpr;
     } else {
       status = MARK_ERR;
       ++err;
@@ -476,6 +587,54 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
   }
 }
 
+template<typename InputIterator>
+static SharedHandle<FileEntry> getFirstRequestedFileEntry
+(InputIterator first, InputIterator last)
+{
+  for(; first != last; ++first) {
+    if((*first)->isRequested()) {
+      return *first;
+    }
+  }
+  return SharedHandle<FileEntry>();
+}
+
+template<typename InputIterator>
+static size_t countRequestedFileEntry(InputIterator first, InputIterator last)
+{
+  size_t count = 0;
+  for(; first != last; ++first) {
+    if((*first)->isRequested()) {
+      ++count;
+    }
+  }
+  return count;
+}
+
+template<typename InputIterator>
+static void writeFilePath
+(InputIterator first, InputIterator last, std::ostream& o, bool memory)
+{
+  SharedHandle<FileEntry> e = getFirstRequestedFileEntry(first, last);
+  if(e.isNull()) {
+    o << "n/a";
+  } else {
+    if(e->getPath().empty()) {
+      o << "n/a";
+    } else {
+      if(memory) {
+	o << "[MEMORY]" << File(e->getPath()).getBasename();
+      } else {
+	o << e->getPath();
+      }
+    }
+    size_t count = countRequestedFileEntry(first, last);
+    if(count > 1) {
+      o << " (" << count-1 << "more)";
+    }
+  }
+}
+
 std::string RequestGroupMan::formatDownloadResult(const std::string& status, const DownloadResultHandle& downloadResult) const
 {
   std::stringstream o;
@@ -490,20 +649,16 @@ std::string RequestGroupMan::formatDownloadResult(const std::string& status, con
     o << "n/a";
   }
   o << "|";
-  if(downloadResult->result == DownloadResult::FINISHED) {
-    o << downloadResult->filePath;
+  const std::deque<SharedHandle<FileEntry> >& fileEntries =
+    downloadResult->fileEntries;
+  if(downloadResult->result == DownloadResult::FINISHED ||
+     downloadResult->numUri == 0) {
+    writeFilePath(fileEntries.begin(), fileEntries.end(), o,
+		  downloadResult->inMemoryDownload);
   } else {
-    if(downloadResult->numUri == 0) {
-      if(downloadResult->filePath.empty()) {
-	o << "n/a";
-      } else {
-	o << downloadResult->filePath;
-      }
-    } else {
-      o << downloadResult->uri;
-      if(downloadResult->numUri > 1) {
-	o << " (" << downloadResult->numUri-1 << "more)";
-      }
+    o << downloadResult->uri;
+    if(downloadResult->numUri > 1) {
+      o << " (" << downloadResult->numUri-1 << "more)";
     }
   }
   return o.str();
@@ -574,10 +729,21 @@ TransferStat RequestGroupMan::calculateStat()
   return s;
 }
 
-const std::deque<SharedHandle<DownloadResult> >&
-RequestGroupMan::getDownloadResults() const
+SharedHandle<DownloadResult>
+RequestGroupMan::findDownloadResult(int32_t gid) const
 {
-  return _downloadResults;
+  for(std::deque<SharedHandle<DownloadResult> >::const_iterator i =
+	_downloadResults.begin(); i != _downloadResults.end(); ++i) {
+    if((*i)->gid == gid) {
+      return *i;
+    }
+  }
+  return SharedHandle<DownloadResult>();
+}
+
+void RequestGroupMan::purgeDownloadResult()
+{
+  _downloadResults.clear();
 }
 
 SharedHandle<ServerStat>
