@@ -106,11 +106,6 @@ bool UTPexExtensionMessage::addFreshPeer(const PeerHandle& peer)
   }
 }
 
-const Peers& UTPexExtensionMessage::getFreshPeers() const
-{
-  return _freshPeers;
-}
-
 bool UTPexExtensionMessage::freshPeersAreFull() const
 {
   return _freshPeers.size() >= _maxFreshPeer;
@@ -127,11 +122,6 @@ bool UTPexExtensionMessage::addDroppedPeer(const PeerHandle& peer)
   }
 }
 
-const Peers& UTPexExtensionMessage::getDroppedPeers() const
-{
-  return _droppedPeers;
-}
-
 bool UTPexExtensionMessage::droppedPeersAreFull() const
 {
   return _droppedPeers.size() >= _maxDroppedPeer;
@@ -142,21 +132,11 @@ void UTPexExtensionMessage::setMaxFreshPeer(size_t maxFreshPeer)
   _maxFreshPeer = maxFreshPeer;
 }
 
-size_t UTPexExtensionMessage::getMaxFreshPeer() const
-{
-  return _maxFreshPeer;
-}
-
 void UTPexExtensionMessage::setMaxDroppedPeer(size_t maxDroppedPeer)
 {
   _maxDroppedPeer = maxDroppedPeer;
 }
 
-size_t UTPexExtensionMessage::getMaxDroppedPeer() const
-{
-  return _maxDroppedPeer;
-}
-
 void UTPexExtensionMessage::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
@@ -167,7 +147,7 @@ UTPexExtensionMessageHandle
 UTPexExtensionMessage::create(const unsigned char* data, size_t len)
 {
   if(len < 1) {
-    throw DlAbortEx(StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE,
+    throw DL_ABORT_EX(StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE,
 				 EXTENSION_NAME.c_str(), len).str());
   }
   UTPexExtensionMessageHandle msg(new UTPexExtensionMessage(*data));
