@@ -38,6 +38,7 @@
 #include <fstream>
 #include <algorithm>
 #include <sstream>
+#include <vector>
 
 #include "RequestGroup.h"
 #include "Option.h"
@@ -49,7 +50,7 @@
 #include "UriListParser.h"
 #include "SingleFileDownloadContext.h"
 #include "RecoverableException.h"
-#include "FatalException.h"
+#include "DlAbortEx.h"
 #include "message.h"
 #include "StringFormat.h"
 #include "DefaultBtContext.h"
@@ -59,9 +60,89 @@
 #include "Util.h"
 #include "array_fun.h"
 #include "OptionHandler.h"
+#include "ByteArrayDiskWriter.h"
 
 namespace aria2 {
 
+const std::vector<std::string>& listRequestOptions()
+{
+  static const std::string REQUEST_OPTIONS[] = {
+    PREF_DIR,
+    PREF_CHECK_INTEGRITY,
+    PREF_CONTINUE,
+    PREF_ALL_PROXY,
+    PREF_CONNECT_TIMEOUT,
+    PREF_DRY_RUN,
+    PREF_LOWEST_SPEED_LIMIT,
+    PREF_MAX_FILE_NOT_FOUND,
+    PREF_MAX_TRIES,
+    PREF_NO_PROXY,
+    PREF_OUT,
+    PREF_PROXY_METHOD,
+    PREF_REMOTE_TIME,
+    PREF_RETRY_WAIT,
+    PREF_SPLIT,
+    PREF_TIMEOUT,
+    PREF_HTTP_AUTH_CHALLENGE,
+    PREF_HTTP_USER,
+    PREF_HTTP_PASSWD,
+    PREF_HTTP_PROXY,
+    PREF_HTTPS_PROXY,
+    PREF_REFERER,
+    PREF_ENABLE_HTTP_KEEP_ALIVE,
+    PREF_ENABLE_HTTP_PIPELINING,
+    PREF_HEADER,
+    PREF_USE_HEAD,
+    PREF_USER_AGENT,
+    PREF_FTP_USER,
+    PREF_FTP_PASSWD,
+    PREF_FTP_PASV,
+    PREF_FTP_PROXY,
+    PREF_FTP_TYPE,
+    PREF_FTP_REUSE_CONNECTION,
+    PREF_NO_NETRC,
+    PREF_SELECT_FILE,
+    PREF_BT_EXTERNAL_IP,
+    PREF_BT_HASH_CHECK_SEED,
+    PREF_BT_MAX_OPEN_FILES,
+    PREF_BT_MAX_PEERS,
+    PREF_BT_MIN_CRYPTO_LEVEL,
+    PREF_BT_REQUIRE_CRYPTO,
+    PREF_BT_REQUEST_PEER_SPEED_LIMIT,
+    PREF_BT_SEED_UNVERIFIED,
+    PREF_BT_TRACKER_INTERVAL,
+    PREF_ENABLE_PEER_EXCHANGE,
+    PREF_FOLLOW_TORRENT,
+    PREF_INDEX_OUT,
+    PREF_MAX_UPLOAD_LIMIT,
+    PREF_PEER_ID_PREFIX,
+    PREF_SEED_RATIO,
+    PREF_SEED_TIME,
+    PREF_FOLLOW_METALINK,
+    PREF_METALINK_SERVERS,
+    PREF_METALINK_LANGUAGE,
+    PREF_METALINK_LOCATION,
+    PREF_METALINK_OS,
+    PREF_METALINK_VERSION,
+    PREF_METALINK_PREFERRED_PROTOCOL,
+    PREF_METALINK_ENABLE_UNIQUE_PROTOCOL,
+    PREF_ALLOW_OVERWRITE,
+    PREF_ALLOW_PIECE_LENGTH_CHANGE,
+    PREF_ASYNC_DNS,
+    PREF_AUTO_FILE_RENAMING,
+    PREF_FILE_ALLOCATION,
+    PREF_MAX_DOWNLOAD_LIMIT,
+    PREF_NO_FILE_ALLOCATION_LIMIT,
+    PREF_PARAMETERIZED_URI,
+    PREF_REALTIME_CHUNK_CHECKSUM
+  };
+  static std::vector<std::string> requestOptions
+    (&REQUEST_OPTIONS[0],
+     &REQUEST_OPTIONS[arrayLength(REQUEST_OPTIONS)]);;
+
+  return requestOptions;
+}
+
 static void unfoldURI
 (std::deque<std::string>& result, const std::deque<std::string>& args)
 {
@@ -92,19 +173,19 @@ static void splitURI(std::deque<std::string>& result,
 }
 
 static SharedHandle<RequestGroup> createRequestGroup
-(const Option& op, const std::deque<std::string>& uris,
- const Option& requestOption,
+(const SharedHandle<Option>& option, const std::deque<std::string>& uris,
  bool useOutOption = false)
 {
-  SharedHandle<RequestGroup> rg(new RequestGroup(&op, uris));
+  SharedHandle<RequestGroup> rg(new RequestGroup(option, uris));
   SharedHandle<SingleFileDownloadContext> dctx
-    (new SingleFileDownloadContext(op.getAsInt(PREF_SEGMENT_SIZE),
-				   0,
-				   A2STR::NIL,
-				   useOutOption&&!requestOption.blank(PREF_OUT)?
-				   requestOption.get(PREF_DIR)+"/"+requestOption.get(PREF_OUT):A2STR::NIL));
+    (new SingleFileDownloadContext
+     (option->getAsInt(PREF_SEGMENT_SIZE),
+      0,
+      A2STR::NIL,
+      useOutOption&&!option->blank(PREF_OUT)?
+      option->get(PREF_DIR)+"/"+option->get(PREF_OUT):A2STR::NIL));
 
-  dctx->setDir(requestOption.get(PREF_DIR));
+  dctx->setDir(option->get(PREF_DIR));
   rg->setDownloadContext(dctx);
   return rg;
 }
@@ -114,20 +195,24 @@ static SharedHandle<RequestGroup> createRequestGroup
 static
 SharedHandle<RequestGroup>
 createBtRequestGroup(const std::string& torrentFilePath,
-		     const Option& op,
+		     const SharedHandle<Option>& option,
 		     const std::deque<std::string>& auxUris,
-		     const Option& requestOption)
+		     const std::string& torrentData = "")
 {
-  SharedHandle<RequestGroup> rg(new RequestGroup(&op, auxUris));
+  SharedHandle<RequestGroup> rg(new RequestGroup(option, auxUris));
   SharedHandle<DefaultBtContext> btContext(new DefaultBtContext());
-  btContext->setDir(requestOption.get(PREF_DIR));
-  btContext->load(torrentFilePath);// may throw exception
-  if(op.defined(PREF_PEER_ID_PREFIX)) {
-    btContext->setPeerIdPrefix(op.get(PREF_PEER_ID_PREFIX));
+  btContext->setDir(option->get(PREF_DIR));
+  if(torrentData.empty()) {
+    btContext->load(torrentFilePath);// may throw exception
+  } else {
+    btContext->loadFromMemory(torrentData, "default"); // may throw exception
+  }
+  if(option->defined(PREF_PEER_ID_PREFIX)) {
+    btContext->setPeerIdPrefix(option->get(PREF_PEER_ID_PREFIX));
   }
   btContext->setFileFilter
-    (Util::parseIntRange(requestOption.get(PREF_SELECT_FILE)));
-  std::istringstream indexOutIn(requestOption.get(PREF_INDEX_OUT));
+    (Util::parseIntRange(option->get(PREF_SELECT_FILE)));
+  std::istringstream indexOutIn(option->get(PREF_INDEX_OUT));
   std::map<size_t, std::string> indexPathMap =
     Util::createIndexPathMap(indexOutIn);
   for(std::map<size_t, std::string>::const_iterator i = indexPathMap.begin();
@@ -141,21 +226,24 @@ createBtRequestGroup(const std::string& torrentFilePath,
 }
 
 void createRequestGroupForBitTorrent
-(std::deque<SharedHandle<RequestGroup> >& result, const Option& op,
- const std::deque<std::string>& uris)
+(std::deque<SharedHandle<RequestGroup> >& result,
+ const SharedHandle<Option>& option,
+ const std::deque<std::string>& uris,
+ const std::string& torrentData)
 {
   std::deque<std::string> nargs;
-  if(op.get(PREF_PARAMETERIZED_URI) == V_TRUE) {
+  if(option->get(PREF_PARAMETERIZED_URI) == V_TRUE) {
     unfoldURI(nargs, uris);
   } else {
     nargs = uris;
   }
   // we ignore -Z option here
-  size_t numSplit = op.getAsInt(PREF_SPLIT);
+  size_t numSplit = option->getAsInt(PREF_SPLIT);
   std::deque<std::string> auxUris;
   splitURI(auxUris, nargs.begin(), nargs.end(), numSplit);
   SharedHandle<RequestGroup> rg =
-    createBtRequestGroup(op.get(PREF_TORRENT_FILE), op, auxUris, op);
+    createBtRequestGroup(option->get(PREF_TORRENT_FILE), option, auxUris,
+			 torrentData);
   rg->setNumConcurrentCommand(numSplit);
   result.push_back(rg);
 }
@@ -164,11 +252,21 @@ void createRequestGroupForBitTorrent
 
 #ifdef ENABLE_METALINK
 void createRequestGroupForMetalink
-(std::deque<SharedHandle<RequestGroup> >& result, const Option& op)
+(std::deque<SharedHandle<RequestGroup> >& result,
+ const SharedHandle<Option>& option,
+ const std::string& metalinkData)
 {
-  Metalink2RequestGroup(&op).generate(result, op.get(PREF_METALINK_FILE), op);
+  if(metalinkData.empty()) {
+    Metalink2RequestGroup().generate(result,
+				     option->get(PREF_METALINK_FILE),
+				     option);
+  } else {
+    SharedHandle<ByteArrayDiskWriter> dw(new ByteArrayDiskWriter());
+    dw->setString(metalinkData);
+    Metalink2RequestGroup().generate(result, dw, option);
+  }
   if(result.empty()) {
-    throw FatalException(MSG_NO_FILES_TO_DOWNLOAD);
+    throw DL_ABORT_EX(MSG_NO_FILES_TO_DOWNLOAD);
   }
 }
 #endif // ENABLE_METALINK
@@ -177,34 +275,31 @@ class AccRequestGroup {
 private:
   std::deque<SharedHandle<RequestGroup> >& _requestGroups;
   ProtocolDetector _detector;
-  const Option& _op;
-  const Option& _requestOption;
+  SharedHandle<Option> _option;
 public:
   AccRequestGroup(std::deque<SharedHandle<RequestGroup> >& requestGroups,
-		  const Option& op,
-		  const Option& requestOption):
-    _requestGroups(requestGroups), _op(op), _requestOption(requestOption) {}
+		  const SharedHandle<Option>& option):
+    _requestGroups(requestGroups), _option(option) {}
 
   void
   operator()(const std::string& uri)
   {
     if(_detector.isStreamProtocol(uri)) {
       std::deque<std::string> streamURIs;
-      size_t numSplit = _op.getAsInt(PREF_SPLIT);
+      size_t numSplit = _option->getAsInt(PREF_SPLIT);
       for(size_t i = 0; i < numSplit; ++i) {
 	streamURIs.push_back(uri);
       }
       SharedHandle<RequestGroup> rg =
-	createRequestGroup(_op, streamURIs, _requestOption);
+	createRequestGroup(_option, streamURIs);
       rg->setNumConcurrentCommand(numSplit);
       _requestGroups.push_back(rg);
     }
 #ifdef ENABLE_BITTORRENT
     else if(_detector.guessTorrentFile(uri)) {
       try {
-	_requestGroups.push_back(createBtRequestGroup(uri, _op,
-						      std::deque<std::string>(),
-						      _requestOption));
+	_requestGroups.push_back(createBtRequestGroup(uri, _option,
+						      std::deque<std::string>()));
       } catch(RecoverableException& e) {
 	// error occurred while parsing torrent file.
 	// We simply ignore it.	
@@ -215,8 +310,7 @@ public:
 #ifdef ENABLE_METALINK
     else if(_detector.guessMetalinkFile(uri)) {
       try {
-	Metalink2RequestGroup(&_op).generate(_requestGroups, uri,
-					    _requestOption);
+	Metalink2RequestGroup().generate(_requestGroups, uri, _option);
       } catch(RecoverableException& e) {
 	// error occurred while parsing metalink file.
 	// We simply ignore it.
@@ -239,103 +333,84 @@ public:
   }
 };
 
-static void copyIfndef(Option& dest, const Option& src, const std::string& name)
-{
-  if(!dest.defined(name)) {
-    dest.put(name, src.get(name));
-  }
-}
-
-static void createRequestGroupForUri
-(std::deque<SharedHandle<RequestGroup> >& result, const Option& op,
- const std::deque<std::string>& uris, const Option& requestOption)
+void createRequestGroupForUri
+(std::deque<SharedHandle<RequestGroup> >& result,
+ const SharedHandle<Option>& option,
+ const std::deque<std::string>& uris,
+ bool ignoreForceSequential,
+ bool ignoreNonURI)
 {
   std::deque<std::string> nargs;
-  if(op.get(PREF_PARAMETERIZED_URI) == V_TRUE) {
+  if(option->get(PREF_PARAMETERIZED_URI) == V_TRUE) {
     unfoldURI(nargs, uris);
   } else {
     nargs = uris;
   }
-  if(op.get(PREF_FORCE_SEQUENTIAL) == V_TRUE) {
+  if(!ignoreForceSequential && option->get(PREF_FORCE_SEQUENTIAL) == V_TRUE) {
     std::for_each(nargs.begin(), nargs.end(),
-		  AccRequestGroup(result, op, requestOption));
+		  AccRequestGroup(result, option));
   } else {
     std::deque<std::string>::iterator strmProtoEnd =
       std::stable_partition(nargs.begin(), nargs.end(), StreamProtocolFilter());
     // let's process http/ftp protocols first.
     if(nargs.begin() != strmProtoEnd) {
-      size_t numSplit = op.getAsInt(PREF_SPLIT);
+      size_t numSplit = option->getAsInt(PREF_SPLIT);
       std::deque<std::string> streamURIs;
       splitURI(streamURIs, nargs.begin(), strmProtoEnd,
 	       numSplit);
       SharedHandle<RequestGroup> rg =
-	createRequestGroup(op, streamURIs, requestOption, true);
+	createRequestGroup(option, streamURIs, true);
       rg->setNumConcurrentCommand(numSplit);
       result.push_back(rg);
     }
-    // process remaining URIs(local metalink, BitTorrent files)
-    std::for_each(strmProtoEnd, nargs.end(),
-		  AccRequestGroup(result, op, requestOption));
-  }
-}
-
-void createRequestGroupForUri
-(std::deque<SharedHandle<RequestGroup> >& result, const Option& op,
- const std::deque<std::string>& uris)
-{
-  createRequestGroupForUri(result, op, uris, op);
-}
-
-template<typename InputIterator>
-static void foreachCopyIfndef(InputIterator first, InputIterator last,
-			      Option& dest, const Option& src)
-{
-  for(; first != last; ++first) {
-    copyIfndef(dest, src, *first);
+    if(!ignoreNonURI) {
+      // process remaining URIs(local metalink, BitTorrent files)
+      std::for_each(strmProtoEnd, nargs.end(),
+		    AccRequestGroup(result, option));
+    }
   }
 }
 
 static void createRequestGroupForUriList
-(std::deque<SharedHandle<RequestGroup> >& result, const Option& op,
+(std::deque<SharedHandle<RequestGroup> >& result,
+ const SharedHandle<Option>& option,
  std::istream& in)
 {
   UriListParser p(in);
   while(p.hasNext()) {
     std::deque<std::string> uris;
-    Option requestOption;
-    p.parseNext(uris, requestOption);
+    SharedHandle<Option> tempOption(new Option());
+    p.parseNext(uris, *tempOption.get());
     if(uris.empty()) {
       continue;
     }
-    // TODO use OptionParser to validate the value in the options.
-    // These options can be specified in input list(-i list).
-    static const std::string REQUEST_OPTIONS[] = {
-      PREF_DIR,
-      PREF_OUT,
-      PREF_SELECT_FILE,
-      PREF_INDEX_OUT
-    };
-    foreachCopyIfndef(&REQUEST_OPTIONS[0],
-		      &REQUEST_OPTIONS[arrayLength(REQUEST_OPTIONS)],
-		      requestOption, op);
 
-    createRequestGroupForUri(result, op, uris, requestOption);
+    SharedHandle<Option> requestOption(new Option(*option.get()));
+    for(std::vector<std::string>::const_iterator i =
+	  listRequestOptions().begin(); i != listRequestOptions().end(); ++i) {
+      if(tempOption->defined(*i)) {
+	requestOption->put(*i, tempOption->get(*i));
+      }
+    }
+
+    createRequestGroupForUri(result, requestOption, uris);
   }
 }
 
 void createRequestGroupForUriList
-(std::deque<SharedHandle<RequestGroup> >& result, const Option& op)
+(std::deque<SharedHandle<RequestGroup> >& result,
+ const SharedHandle<Option>& option)
 {
-  if(op.get(PREF_INPUT_FILE) == "-") {
-    createRequestGroupForUriList(result, op, std::cin);
+  if(option->get(PREF_INPUT_FILE) == "-") {
+    createRequestGroupForUriList(result, option, std::cin);
   } else {
-    if(!File(op.get(PREF_INPUT_FILE)).isFile()) {
-      throw FatalException
-	(StringFormat(EX_FILE_OPEN, op.get(PREF_INPUT_FILE).c_str(),
+    if(!File(option->get(PREF_INPUT_FILE)).isFile()) {
+      throw DL_ABORT_EX
+	(StringFormat(EX_FILE_OPEN, option->get(PREF_INPUT_FILE).c_str(),
 		      "No such file").str());
     }
-    std::ifstream f(op.get(PREF_INPUT_FILE).c_str(), std::ios::binary);
-    createRequestGroupForUriList(result, op, f);
+    std::ifstream f(option->get(PREF_INPUT_FILE).c_str(), std::ios::binary);
+    createRequestGroupForUriList(result, option, f);
   }
 }
 
